==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-70.js <==
dispMUA.arDispMUAAllocation["p"] =
{
  "posta elettronica internet di microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "plaasoft technologies php-mailer" : [ "plaasoft.png" , "http://www.plaasoft.com/" ] ,
  "produced by pioneer investments" : [ "pioneerinvestments.png" , "http://www.pioneerinvestments.de/" ] ,
  "produced by microsoft exchange" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "produced by microsoft mimeole" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "paradise fast delivery agent" : [ "pfda.png" , "http://fda.omnisci.jp/FDA.html" ] ,
  "produced by confixx webmail" : [ "confixx.png" , "http://www.parallels.com/de/products/confixx/" ] ,
  "protagona email services" : [ "protagona.png" ] ,
  "prospero mailing system" : [ "prospero.png" , "http://www.prospero.com/" ] ,
  "produced by swiftmailer" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "produced by msn mimeole" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "poczta.petroinform.net" : [ "petroinform_net.png" , "http://poczta.petroinform.net/" ] ,
  "pw-internet solutions" : [ "pw-internet.png" , "http://www.pw-internet.de/" ] ,
  "produced by nespresso" : [ "nespresso.png" , "http://www.nespresso.com/" ] ,
  "postmaster zonereg.ru" : [ "zonereg_ru.png" , "http://zonereg.ru/" ] ,
  "pop3/smtp emailplugin" : [ "pop3smtp-emailplugin.png" , "http://www.andremartin.de/POP3Plugin/" ] ,
  "poczta systemu ramzes" : [ "ramzes.png" , "http://www.ramzes.lubin.pl/" ] ,
  "phpmail (c) funmail2u" : [ "funmail2u.png" , "http://www.funmail2u.de/" ] ,
  "produced by mailworx" : [ "mailworx.png" , "http://www.mailworx.info/" ] ,
  "produced by myvideo" : [ "myvideo.png" , "http://www.myvideo.de/" ] ,
  "powered by flowfact" : [ "flowfact.png" , "http://www.flowfact.de/" ] ,
  "poplist mailinglist" : [ "poplist.png" ] ,
  "produced by phpbb2" : [ "phpbb2.png" , "http://www.phpbb2.de/" ] ,
  "postmaster general" : [ "usps.png" , "http://www.postmastergeneral.com/" ] ,
  "pg-mailinglist pro" : [ "raynette.png" , "http://www.raynette.fr/script-pro/newsletter-mailing-list/" ] ,
  "penn state webmail" : [ "penn_state.png" , "http://webmail.psu.edu/" ] ,
  "push.infojobs.net" : [ "infojobs_net.png" , "http://www.infojobs.net/" ] ,
  "produced by eworx" : [ "eworx.png" , "http://www.eworx.at/" ] ,
  "pixum-html-mailer" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "projectplace.com" : [ "projectplace_com.png" , "http://www.projectplace.com/" ] ,
  "present perfect!" : [ "speech-design.png" , "http://www.speech-design.com/" ] ,
  "pixum newsletter" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "pinuts universal" : [ "pinuts.png" , "http://www.pinuts.de/Loesungen/universal_messenger/um_newsletter-edition/" ] ,
  "papageno gateway" : [ "papageno.png" , "http://www.com-em-tex.de/" ] ,
  "python syncmail" : [ "python-syncmail.png" , "http://sourceforge.net/projects/cvs-syncmail/" ] ,
  "popmail-conduit" : [ "kde.png" , "http://pim.kde.org/" ] ,
  "pld linux kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
  "ptmail webmail" : [ "ptmail.png" ] ,
  "postinoclassic" : [ "postino.png" , "http://www.syscli.co.jp/" ] ,
  "poczta gery.pl" : [ "gery_pl.png" , "http://www.gery.pl/" ] ,
  "pocket wz mail" : [ "pocket-wz.png" , "http://www.villagecenter.co.jp/soft/pwz30/" ] ,
  "pineapple news" : [ "pineapplenews.png" , "http://www.platinumball.net/pineapple/news/macosx/" ] ,
  "phaser 6180mfp" : [ "xerox.png" , "http://www.xeroxdirect.com/" ] ,
  "polibuda.info" : [ "polibuda.png" , "http://www.polibuda.info/" ] ,
  "plentymarkets" : [ "plentymarkets.png" , "http://www.plentysystems.de/" ] ,
  "punbb mailer" : [ "punbb.png" , "http://punbb.informer.com/" ] ,
  "phoenix mail" : [ "phoenix_mail.png" , "http://phxmail.sourceforge.net/" ] ,
  "powermail -" : [ "powermail.png" , "http://www.indosolution.com/" ] ,
  "poem mailer" : [ "poem-mailer.png" , "http://poem.crmstyle.com/" ] ,
  "php/popmail" : [ "tinned-mail.png" , "http://www.tinned-mail.net/" ] ,
  "prosite.de" : [ "prosite_de.png" , "http://www.prosite.de/" ] ,
  "pop peeper" : [ "poppeeper.png" , "http://www.poppeeper.com/" ] ,
  "pol-system" : [ "pol_system.png" ] ,
  "pandoemail" : [ "pando.png" , "http://www.pando.com/" ] ,
  "protoplex" : [ "protoplex.png" , "http://www.protoplex.ru/" ] ,
  "praktomat" : [ "praktomat.png" , "http://www.fim.uni-passau.de/de/fim/fakultaet/lehrstuehle/softwaresysteme/forschung/praktomat.html" ] ,
  "postino v" : [ "postino.png" , "http://www.syscli.co.jp/" ] ,
  "po4ta.com" : [ "po4ta_com.png" , "http://www.po4ta.com/" ] ,
  "pluriform" : [ "pluriform.png" , "http://www.pluriform.nl/" ] ,
  "phpmailer" : [ "phpmailer.png" , "http://phpmailer.codeworxtech.com/" ] ,
  "phpcurve/" : [ "phpcurve.png" , "http://www.itzikdesign.com/" ] ,
  "php-email" : [ "codewalkers.png" , "http://www.codewalkers.com/c/a/Email-Code/PHP-Text-HTML-Email-with-Attachments-21/" ] ,
  "pb stores" : [ "packardbell.png" , "http://www.packardbell.com/" ] ,
  "paranmail" : [ "paran.png" , "http://mail.paran.com/" ] ,
  "pronews/" : [ "pronews.png" ] ,
  "pro dada" : [ "dada_mail.png" , "http://dadamailproject.com/purchase/pro.html" ] ,
  "prayer v" : [ "hermes_cambridge.png" ] ,
  "popmail/" : [ "popmail.png" , "http://www1.umn.edu/adcs/help/email/MacPopmail.html" ] ,
  "popmail " : [ "popmail.png" , "http://www1.umn.edu/adcs/help/email/MacPopmail.html" ] ,
  "pocomail" : [ "pocomail.png" , "http://www.pocosystems.com/" ] ,
  "platypus" : [ "platypus.png" , "http://www.mcga.com.au/platypus.php" ] ,
  "phlymail" : [ "phlymail.png" , "http://phlymail.com/" ] ,
  "postpet" : [ "postpet.png" , "http://www.postpet.so-net.ne.jp/" ] ,
  "postaci" : [ "postaci.png" , "http://www.postaciwebmail.org/" ] ,
  "porsche" : [ "porsche.png" , "http://www.porsche.com/" ] ,
  "pnphpbb" : [ "pnphpbb.png" , "http://www.pnphpbb.com/" ] ,
  "pminews" : [ "pminews.png" , "http://www.stardock.com/products/pminews/" ] ,
  "phplist" : [ "phplist.png" , "http://www.phplist.com" ] ,
  "phorum5" : [ "phorum5.png" , "http://www.phorum.org/phorum5/" ] ,
  "pegasus" : [ "pegasus.png" , "http://www.pmail.com/" ] ,
  "pbemail" : [ "perfectionbytes.png" , "http://www.perfectionbytes.com/" ] ,
  "papyrus" : [ "papyrus_de.png" , "http://www.papyrus.de/" ] ,
  "python" : [ "python.png" , "http://www.python.org/" ] ,
  "pymail" : [ "python.png" , "http://www.python.org/" ] ,
  "postme" : [ "postme.png" ] ,
  "postie" : [ "postie.png" , "http://www.infradig.com/postie/" ] ,
  "pmw-tb" : [ "thunderbird.png" , "http://www.mozilla.com/thunderbird/" ] ,
  "pmmail" : [ "pmmail.png" , "http://www.pmmail2000.com/" ] ,
  "pluto/" : [ "pluto.png" , "http://home.clara.net/jsd/" ] ,
  "paypal" : [ "paypal.png" , "http://www.paypal.com/" ] ,
  "paseri" : [ "paseri.png" , "http://www.nippon-control-system.co.jp/products/paseri/" ] ,
  "papaya" : [ "papaya.png" , "http://www.papaya-cms.com/" ] ,
  "panini" : [ "panini-comics.png" , "http://www.paninicomics.de/" ] ,
  "pochy" : [ "pochy.png" , "http://pochy.sourceforge.jp/" ] ,
  "pobox" : [ "pobox.png" ] ,
  "pmail" : [ "pegasus.png" , "http://www.pmail.com/" ] ,
  "phpbb" : [ "phpbb.png" , "http://www.phpbb.com/" ] ,
  "poco" : [ "pocomail.png" , "http://www.pocosystems.com/" ] ,
  "pine" : [ "pine.png" , "http://www.washington.edu/pine/" ] ,
  "php5" : [ "php.png" , "http://www.php.net/" ] ,
  "php4" : [ "php.png" , "http://www.php.net/" ] ,
  "php3" : [ "php.png" , "http://www.php.net/" ] ,
  "php2" : [ "php.png" , "http://www.php.net/" ] ,
  "php1" : [ "php.png" , "http://www.php.net/" ] ,
  "php/" : [ "php.png" , "http://www.php.net/" ] ,
  "php " : [ "php.png" , "http://www.php.net/" ] ,
  "perl" : [ "perl.png" , "http://www.perl.org/" ] ,
  "pepr" : [ "pear.png" , "http://pear.php.net/" ] ,
  "pear" : [ "pear.png" , "http://pear.php.net/" ] ,
  "pan/" : [ "pan.png" , "http://pan.rebelbase.com/" ] ,
  "pan " : [ "pan.png" , "http://pan.rebelbase.com/" ] ,
  "pse" : [ "interia_pl.png" , "http://www.interia.pl/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-70.js <==
dispMUA.arDispMUAAllocation["p"] =
{
  "posta elettronica internet di microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "plaasoft technologies php-mailer" : [ "plaasoft.png" , "http://www.plaasoft.com/" ] ,
  "produced by pioneer investments" : [ "pioneerinvestments.png" , "http://www.pioneerinvestments.de/" ] ,
  "provcomm java framework mailer" : [ "java.png" , "http://www.provcomm.com/" ] ,
  "produced by microsoft exchange" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "produced by microsoft mimeole" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "paradise fast delivery agent" : [ "pfda.png" , "http://fda.omnisci.jp/FDA.html" ] ,
  "produced by confixx webmail" : [ "confixx.png" , "http://www.parallels.com/de/products/confixx/" ] ,
  "postmaster 1.1.1 for beos" : [ "beos_postmaster.png" , "http://kennyc.com/postmaster" ] ,
  "protagona email services" : [ "protagona.png" , "http://www.protagona.com/" ] ,
  "prospero mailing system" : [ "prospero.png" , "http://www.prospero.com/" ] ,
  "produced by swiftmailer" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "produced by msn mimeole" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "poczta.petroinform.net" : [ "petroinform_net.png" , "http://poczta.petroinform.net/" ] ,
  "pw-internet solutions" : [ "pw-internet.png" , "http://www.pw-internet.de/" ] ,
  "produced by nespresso" : [ "nespresso.png" , "http://www.nespresso.com/" ] ,
  "postmaster zonereg.ru" : [ "zonereg_ru.png" , "http://zonereg.ru/" ] ,
  "pop3/smtp emailplugin" : [ "pop3smtp-emailplugin.png" , "http://www.andremartin.de/POP3Plugin/" ] ,
  "poczta systemu ramzes" : [ "ramzes.png" , "http://www.ramzes.lubin.pl/" ] ,
  "phpmail (c) funmail2u" : [ "funmail2u.png" , "http://www.funmail2u.de/" ] ,
  "produced by mailworx" : [ "mailworx.png" , "http://www.mailworx.info/" ] ,
  "produced by myvideo" : [ "myvideo.png" , "http://www.myvideo.de/" ] ,
  "powered by flowfact" : [ "flowfact.png" , "http://www.flowfact.de/" ] ,
  "poplist mailinglist" : [ "poplist.png" ] ,
  "produced by phpbb2" : [ "phpbb2.png" , "http://www.phpbb2.de/" ] ,
  "postmaster general" : [ "usps.png" , "http://www.postmastergeneral.com/" ] ,
  "pg-mailinglist pro" : [ "raynette.png" , "http://www.raynette.fr/script-pro/newsletter-mailing-list/" ] ,
  "penn state webmail" : [ "penn_state.png" , "http://webmail.psu.edu/" ] ,
  "push.infojobs.net" : [ "infojobs_net.png" , "http://www.infojobs.net/" ] ,
  "produced by eworx" : [ "eworx.png" , "http://www.eworx.at/" ] ,
  "pixum-html-mailer" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "projectplace.com" : [ "projectplace_com.png" , "http://www.projectplace.com/" ] ,
  "priscillapostman" : [ "priscilla.png" , "http://priscilla.plasticjumper.it/" ] ,
  "present perfect!" : [ "speech-design.png" , "http://www.speech-design.com/" ] ,
  "pixum newsletter" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "pinuts universal" : [ "pinuts.png" , "http://www.pinuts.de/Loesungen/universal_messenger/um_newsletter-edition/" ] ,
  "papageno gateway" : [ "papageno.png" , "http://www.com-em-tex.de/" ] ,
  "python syncmail" : [ "python-syncmail.png" , "http://sourceforge.net/projects/cvs-syncmail/" ] ,
  "popmail-conduit" : [ "kde.png" , "http://pim.kde.org/" ] ,
  "pld linux kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
  "ptmail webmail" : [ "ptmail.png" ] ,
  "pt startmailer" : [ "powertech.png" , "http://www.powertech.no/" ] ,
  "pr_cron_mailer" : [ "juniper.png" , "http://www.juniper.net/" ] ,
  "postinoclassic" : [ "postino.png" , "http://www.syscli.co.jp/" ] ,
  "poczta gery.pl" : [ "gery_pl.png" , "http://www.gery.pl/" ] ,
  "pocket wz mail" : [ "pocket-wz.png" , "http://www.villagecenter.co.jp/soft/pwz30/" ] ,
  "piratesassault" : [ "piratesassault.png" , "http://www.piratesassault.de/" ] ,
  "pineapple news" : [ "pineapplenews.png" , "http://www.platinumball.net/pineapple/news/macosx/" ] ,
  "phaser 6180mfp" : [ "xerox.png" , "http://www.xeroxdirect.com/" ] ,
  "polibuda.info" : [ "polibuda.png" , "http://www.polibuda.info/" ] ,
  "plentymarkets" : [ "plentymarkets.png" , "http://www.plentysystems.de/" ] ,
  "punbb mailer" : [ "punbb.png" , "http://punbb.informer.com/" ] ,
  "phpmail tool" : [ "php.png" , "" ] ,
  "phoenix mail" : [ "phoenix_mail.png" , "http://phxmail.sourceforge.net/" ] ,
  "powermail -" : [ "powermail.png" , "http://www.indosolution.com/" ] ,
  "poem mailer" : [ "poem-mailer.png" , "http://poem.crmstyle.com/" ] ,
  "php/popmail" : [ "tinned-mail.png" , "http://www.tinned-mail.net/" ] ,
  "prosite.de" : [ "prosite_de.png" , "http://www.prosite.de/" ] ,
  "pop peeper" : [ "poppeeper.png" , "http://www.poppeeper.com/" ] ,
  "pol-system" : [ "pol_system.png" ] ,
  "pandoemail" : [ "pando.png" , "http://www.pando.com/" ] ,
  "protoplex" : [ "protoplex.png" , "http://www.protoplex.ru/" ] ,
  "praktomat" : [ "praktomat.png" , "http://www.fim.uni-passau.de/de/fim/fakultaet/lehrstuehle/softwaresysteme/forschung/praktomat.html" ] ,
  "postino v" : [ "postino.png" , "http://www.syscli.co.jp/" ] ,
  "po4ta.com" : [ "po4ta_com.png" , "http://www.po4ta.com/" ] ,
  "pluriform" : [ "pluriform.png" , "http://www.pluriform.nl/" ] ,
  "phpmailer" : [ "phpmailer.png" , "http://phpmailer.codeworxtech.com/" ] ,
  "phpcurve/" : [ "phpcurve.png" , "http://www.itzikdesign.com/" ] ,
  "php-email" : [ "codewalkers.png" , "http://www.codewalkers.com/c/a/Email-Code/PHP-Text-HTML-Email-with-Attachments-21/" ] ,
  "pb stores" : [ "packardbell.png" , "http://www.packardbell.com/" ] ,
  "paranmail" : [ "paran.png" , "http://mail.paran.com/" ] ,
  "pukiwiki" : [ "pukiwiki.png" , "http://pukiwiki.sourceforge.jp/" ] ,
  "pronews/" : [ "pronews.png" ] ,
  "pro dada" : [ "dada_mail.png" , "http://dadamailproject.com/purchase/pro.html" ] ,
  "prayer v" : [ "hermes_cambridge.png" ] ,
  "popmail/" : [ "popmail.png" , "http://www1.umn.edu/adcs/help/email/MacPopmail.html" ] ,
  "popmail " : [ "popmail.png" , "http://www1.umn.edu/adcs/help/email/MacPopmail.html" ] ,
  "pocomail" : [ "pocomail.png" , "http://www.pocosystems.com/" ] ,
  "platypus" : [ "platypus.png" , "http://www.mcga.com.au/platypus.php" ] ,
  "phlymail" : [ "phlymail.png" , "http://phlymail.com/" ] ,
  "p3mailer" : [ "php.png" , "http://sourceforge.net/projects/p3mailer" ] ,
  "postpet" : [ "postpet.png" , "http://www.postpet.so-net.ne.jp/" ] ,
  "postbox" : [ "postbox.png" , "http://www.postbox-inc.com/" ] ,
  "postaci" : [ "postaci.png" , "http://www.postaciwebmail.org/" ] ,
  "porsche" : [ "porsche.png" , "http://www.porsche.com/" ] ,
  "pnphpbb" : [ "pnphpbb.png" , "http://www.pnphpbb.com/" ] ,
  "pminews" : [ "pminews.png" , "http://www.stardock.com/products/pminews/" ] ,
  "phplist" : [ "phplist.png" , "http://www.phplist.com" ] ,
  "phorum5" : [ "phorum5.png" , "http://www.phorum.org/phorum5/" ] ,
  "pegasus" : [ "pegasus.png" , "http://www.pmail.com/" ] ,
  "pbemail" : [ "perfectionbytes.png" , "http://www.perfectionbytes.com/" ] ,
  "papyrus" : [ "papyrus_de.png" , "http://www.papyrus.de/" ] ,
  "python" : [ "python.png" , "http://www.python.org/" ] ,
  "pymail" : [ "python.png" , "http://www.python.org/" ] ,
  "postme" : [ "postme.png" ] ,
  "postie" : [ "postie.png" , "http://www.infradig.com/postie/" ] ,
  "pmw-tb" : [ "thunderbird.png" , "http://www.mozilla.com/thunderbird/" ] ,
  "pmmail" : [ "pmmail.png" , "http://www.pmmail2000.com/" ] ,
  "pluto/" : [ "pluto.png" , "http://home.clara.net/jsd/" ] ,
  "pdsoft" : [ "pdsoft.png" , "http://www.pdeemsoftware.com/" ] ,
  "paypal" : [ "paypal.png" , "http://www.paypal.com/" ] ,
  "paseri" : [ "paseri.png" , "http://www.nippon-control-system.co.jp/products/paseri/" ] ,
  "papaya" : [ "papaya.png" , "http://www.papaya-cms.com/" ] ,
  "panini" : [ "panini-comics.png" , "http://www.paninicomics.de/" ] ,
  "pochy" : [ "pochy.png" , "http://pochy.sourceforge.jp/" ] ,
  "pobox" : [ "pobox.png" ] ,
  "pmail" : [ "pegasus.png" , "http://www.pmail.com/" ] ,
  "phpbb" : [ "phpbb.png" , "http://www.phpbb.com/" ] ,
  "phamm" : [ "phamm.png" , "http://www.phamm.org/" ] ,
  "poco" : [ "pocomail.png" , "http://www.pocosystems.com/" ] ,
  "pine" : [ "pine.png" , "http://www.washington.edu/pine/" ] ,
  "php5" : [ "php.png" , "http://www.php.net/" ] ,
  "php4" : [ "php.png" , "http://www.php.net/" ] ,
  "php3" : [ "php.png" , "http://www.php.net/" ] ,
  "php2" : [ "php.png" , "http://www.php.net/" ] ,
  "php1" : [ "php.png" , "http://www.php.net/" ] ,
  "php/" : [ "php.png" , "http://www.php.net/" ] ,
  "php-" : [ "php.png" , "http://www.php.net/" ] ,
  "php " : [ "php.png" , "http://www.php.net/" ] ,
  "perl" : [ "perl.png" , "http://www.perl.org/" ] ,
  "pepr" : [ "pear.png" , "http://pear.php.net/" ] ,
  "pear" : [ "pear.png" , "http://pear.php.net/" ] ,
  "pan/" : [ "pan.png" , "http://pan.rebelbase.com/" ] ,
  "pan " : [ "pan.png" , "http://pan.rebelbase.com/" ] ,
  "pse" : [ "interia_pl.png" , "http://www.interia.pl/" ] ,
}
